///////////////////////////////////////////////////////////////////////////////////////////////////
//
//
// Comments:
//
// The user must take special care in keeping track of which overlay ID# corresponds with which
// particular overlay region! This is very important here for this exercise because we're dealing
// with both PM and DM overlay regions! (This can become quite cumbersome when using a significant
// number of overlay modules in a system.)
//
// An excerpt for the "live" addresses for the overlay modules from the ldf below...
//
// mem_ovl1_liv_space	{ TYPE(PM RAM) START(0x200000) END(0x2000ff) WIDTH(24) }
// mem_ovl2_liv_space	{ TYPE(PM RAM) START(0x200100) END(0x2001ff) WIDTH(24) }
// mem_ovl3_liv_space	{ TYPE(PM RAM) START(0x200200) END(0x2002ff) WIDTH(24) }
// mem_ovl4_liv_space	{ TYPE(DM RAM) START(0x200700) END(0x2007ff) WIDTH(16) }
// mem_ovl5_liv_space	{ TYPE(DM RAM) START(0x200800) END(0x2008ff) WIDTH(16) }
// mem_ovl6_liv_space	{ TYPE(DM RAM) START(0x200900) END(0x2009ff) WIDTH(16) }
//
///////////////////////////////////////////////////////////////////////////////////////////////////

#define 	NUM_OVLY		7		// This constant defines the number of software overlays in the system

.section/pm seg_pmdata;

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// the 'init24' qualifier is needed here to properly align the 'live addresses' for the overlay into a 24-bit field
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

.var/init24 liveAddresses[NUM_OVLY] =	0x200000,	// live address for overlay #1 (PM)
																			0x200100,	// live address for overlay #2 (PM)
																			0x200200,	// live address for overlay #3 (PM)
																			0x200300, // live address for overlay #4 (PM)
																			0x200700,	// live address for overlay #5 (DM)
																			0x200800,	// live address for overlay #6 (DM)
																			0x200900;	// live address for overlay #7 (DM)

/////////////////////////////////////////////////////////////////////////////////////////////////////
// We need to manually load in the run word size of the overlay module here ourselves. We can easily
// get this information from the map file generated by the linker. (Please ensure that you have
// selected the "generate map file" option from the linker property tab of the project option page!!
/////////////////////////////////////////////////////////////////////////////////////////////////////

.var runWordSize[NUM_OVLY] =	0x005b,	// run word size for overlay #1 (# of internal PM words)
															0x0060,	// run word size for overlay #2 (# of internal PM words)
															0x005b,	// run word size for overlay #3 (# of internal PM words)
															0x0049, // run word size for overlay #4 (# of internal PM words)
															0x0037,	// run word size for overlay #5 (# of internal DM words)
															0x0032,	// run word size for overlay #6 (# of internal DM words)
															0x0028;	// run word size for overlay #7 (# of internal DM words)

/////////////////////////////////////////////////////////////////////////////////////////////////////
// We need to manually load in the live word size of the overlay module here ourselves. This
// array MUST contain the same contents as the above "runWordSize" array, since the hardware logic
// of the ADSP-2191 will perform all of the data packing/unpacking for us.
/////////////////////////////////////////////////////////////////////////////////////////////////////

.var liveWordSize[NUM_OVLY] =	0x005b,	// live word size for overlay #1 (# of external PM words)
															0x0060,	// live word size for overlay #2 (# of external PM words)
															0x005b,	// live word size for overlay #3 (# of external PM words)
															0x0049, // live word size for overlay #4 (# of external PM words)
															0x0037,	// live word size for overlay #5 (# of external DM words)
															0x0032,	// live word size for overlay #6 (# of external DM words)
															0x0028;	// live word size for overlay #7 (# of external DM words)

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Since we define the overlay run address at runtime via the overlay manager, we do not need to declare the run
// addresses for the overlay modules below!!!
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//.var runAddresses[NUM_OVLY];

//////////////////////////////////////////////////////////////////////////////
// Make all of the buffer labels global for the overlay manager
//////////////////////////////////////////////////////////////////////////////

.global liveAddresses;
.global runWordSize;
.global liveWordSize;

